pub struct TimestampQuery { /* private fields */ }Expand description
Allows you to obtain the timestamp inside the OpenGL commands queue.
When you call functions in glium, they are not instantly executed. Instead they are added in a commands queue that the backend executes asynchronously.
When you call TimestampQuery::new, a command is added to this list asking the
backend to send us the current timestamp. Thanks to this, you can know how much time
it takes to execute commands.
Example
let before = glium::debug::TimestampQuery::new(&display);
// do some stuff here
let after = glium::debug::TimestampQuery::new(&display);
match (after, before) {
(Some(after), Some(before)) => {
let elapsed = after.get() - before.get();
println!("Time it took to do stuff: {}", elapsed);
},
_ => ()
}Implementations
Sourceimpl TimestampQuery
impl TimestampQuery
Sourcepub fn new<F>(facade: &F) -> Option<TimestampQuery>
pub fn new<F>(facade: &F) -> Option<TimestampQuery>
Creates a new TimestampQuery. Returns None if the backend doesn’t support it.